@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2025 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 20251019.1621
-;; Package-Revision: e825ae668de6
+;; Package-Version: 20251113.1422
+;; Package-Revision: f30ffdf6e270
 ;; URL: https://github.com/jamescherti/easysession.el
 ;; Keywords: convenience
 ;; Package-Requires: ((emacs "25.1"))
@@ -867,10 +867,9 @@ Also checks if `easysession-dont-save' is set to t."
 (defun easysession--exists (session-name)
   "Check if a session with the given SESSION-NAME exists.
 Returns the session file if the session file exists, nil otherwise."
-  (let ((file-name-handler-alist nil))
-    (let ((file-name (easysession-get-session-file-path session-name)))
-      (when (file-exists-p file-name)
-        file-name))))
+  (let ((file-name (easysession-get-session-file-path session-name)))
+    (when (file-exists-p file-name)
+      file-name)))
 
 (defun easysession--auto-save ()
   "Save the session automatically based on the auto-save predicate.
@@ -1292,9 +1291,7 @@ SESSION-NAME is the session name."
   (setq easysession-load-in-progress nil)
   (setq easysession--load-error t)
 
-  (let* ((original-file-name-handler-alist file-name-handler-alist)
-         (file-name-handler-alist nil)
-         (session-name (if session-name
+  (let* ((session-name (if session-name
                            session-name
                          (if easysession--current-session-name
                              easysession--current-session-name
@@ -1331,20 +1328,19 @@ SESSION-NAME is the session name."
         ;; Load buffers first because the cursor, window-start, or hscroll
         ;; might be altered by packages such as saveplace. This will allow
         ;; the frameset to modify the cursor later on.
-        (let ((file-name-handler-alist original-file-name-handler-alist))
-          (run-hooks 'easysession-before-load-hook)
+        (run-hooks 'easysession-before-load-hook)
 
-          (dolist (handler (easysession-get-load-handlers))
-            (when handler
-              (cond
-               ((and (symbolp handler)
-                     (fboundp handler))
-                (funcall handler session-data))
+        (dolist (handler (easysession-get-load-handlers))
+          (when handler
+            (cond
+             ((and (symbolp handler)
+                   (fboundp handler))
+              (funcall handler session-data))
 
-               (t
-                (easysession--warning
-                 "The following load handler is not a defined function: %s"
-                 handler))))))
+             (t
+              (easysession--warning
+               "The following load handler is not a defined function: %s"
+               handler)))))
 
         ;; Load the frame set
         (easysession--load-frameset session-data
@@ -1357,8 +1353,7 @@ SESSION-NAME is the session name."
 
         (easysession-set-current-session-name session-name)
 
-        (let ((file-name-handler-alist original-file-name-handler-alist))
-          (run-hooks 'easysession-after-load-hook)))))
+        (run-hooks 'easysession-after-load-hook))))
   ;; Return easysession--load-error
   (not easysession--load-error))
 
@@ -1417,9 +1412,7 @@ SESSION-NAME is the name of the session."
                 "Load a session with `easysession-switch-to'"))
 
   (run-hooks 'easysession-before-save-hook)
-  (let* ((original-file-name-handler-alist file-name-handler-alist)
-         (file-name-handler-alist nil)
-         (session-name (if session-name
+  (let* ((session-name (if session-name
                            session-name
                          easysession--current-session-name))
          (session-file (easysession-get-session-file-path session-name))
@@ -1433,8 +1426,7 @@ SESSION-NAME is the name of the session."
     (push (cons "frameset-geo" data-frameset-geometry) session-data)
 
     ;; Buffers and file buffers
-    (let* ((file-name-handler-alist original-file-name-handler-alist)
-           (buffers (funcall easysession-buffer-list-function)))
+    (let* ((buffers (funcall easysession-buffer-list-function)))
       (dolist (handler (easysession-get-save-handlers))
         (if (not (and handler
                       (symbolp handler)
@@ -1469,8 +1461,7 @@ SESSION-NAME is the name of the session."
     (unless (file-directory-p session-dir)
       (make-directory session-dir :parents))
 
-    (let* ((file-name-handler-alist nil)
-           (serialized-data (prin1-to-string session-data)))
+    (let* ((serialized-data (prin1-to-string session-data)))
       (with-temp-buffer
         (insert serialized-data)
         (let ((coding-system-for-write 'utf-8-emacs)
@@ -1575,7 +1566,7 @@ accordingly."
 
 ;;;###autoload
 (define-minor-mode easysession-save-mode
-  "Toggle `easysession-save-mode'."
+  "Persist and restore your sessions."
   :global t
   :lighter (:eval
             (if easysession-save-mode-lighter-show-session-name
